#<%= _.slugify(projectSlug) %>

The `<%= _.slugify(projectSlug) %>` Adaptive.js project.

For information on using Adaptive.js, checkout the [documentation](https://cloud.mobify.com/docs/adaptivejs/).
Contact <support@mobify.com> for assistance.

## Quickstart

Adaptive.js is a JavaScript framework for dynamically adapting websites for
smartphone, tablet and other devices. It consists of:
- A JavaScript SDK for adapting webpages.
- Grunt tasks for developing and deploying completed adaptations as a "bundle".

This project contains specific adaptation for `<%= _.slugify(projectSlug) %>`.

Adaptive.js relies on:
- The [Mobify Tag](http://adaptivejs.mobify.com/) to start the adaptation and load the bundle.
- The [Mobify Cloud](http://cloud.mobify.com/) to distributes bundles to 👨👩👧👦 around the 🌎🌍🌏.
- The open source [Node.js](https://nodejs.org/en/about/) JavaScript framework.
- The open source [Grunt](http://gruntjs.com/) task runner.

Follow these steps to install and run the project:

```sh
# Install a compatible version of Node and verify that it works. Adaptive.js is
# tested on Node versions ^0.10.x.
open https://nodejs.org/
node --version

# Use NPM, the Node package manager, to install Grunt:
npm install -g grunt-cli

# Clone this project:
git clone https://github.com/mobify/<%= _.slugify(projectSlug) %>.git ; cd <%= _.slugify(projectSlug) %>

# Use NPM to install the project specific dependencies:
npm install

# Run the Adaptive.js development server using the Grunt task runner:
grunt preview

# The Adaptive.js development server prints a preview link to load this project
# from your computer. Open it in your browser to load the adaptation. The
# development server automatically rebuilds edited files. See the Adaptive.js
# documentation for more information on building using Adaptive.js:
open https://adaptivejs.mobify.com

# When you're ready to share your adaptation, you'll need to upload it as a
# bundle to the Mobify Cloud. First, find and save your API key:
open https://cloud.mobify.com/account/
grunt adaptive-save_credentials --user="$EMAIL" --key="$APIKEY"

# Now upload a your bundle to share it!
grunt upload

# If you're feeling lucky, deploy your changes straight to prod ;)
grunt upload --deploy-to-target production
```

## Project Information

- **Project Slug**: <%= _.slugify(projectSlug) %>
- **Site URL**: <%= siteUrl %>
- **Generated by**: generator-adaptivejs@<%= generatorVersion %>

## Grunt Tasks

Adaptive.js uses the [Grunt](http://gruntjs.com/) task runner to manage common
development, testing and deployment tasks.

### `grunt` or `grunt help`

Prints to the terminal a list of commonly used Adaptive.js Grunt tasks along with their options.

### `grunt preview`

Starts the development server and outputs a preview link to load files from your
computer. Follow the link in your browser to load the local bundle. Edited
files are rebuilt automatically. By default, the server is set on HTTP port 8080
and HTTPS port 8443. Use the `--port` flag to set a custom HTTP port and `--https-port`
to set a custom HTTPS port.

[Check out the docs for more information](https://cloud.mobify.com/docs/adaptivejs/getting-started/#/previewing-your-adaptation/).

### `grunt push`

Uploads the local bundle to the [Mobify Cloud](https://cloud.mobify.com/) for
publishing. Use the `--message|-m` flag set the bundle label.

```sh
grunt push --message "v1.24.1: Fixes product description page regression."
```

### `grunt lint`

Runs eslint against the project, ensuring that code style and syntax are correct. For more information on lint errors, please see [eslint.org](http://eslint.org/docs/rules/).

To find out more about Mobify's code style rules, please see the [Mobify Code Style](https://github.com/mobify/mobify-code-style) repository.

### `grunt test`

Runs unit and integration tests:

```
# Run tests:
grunt test

# Run tests whose name matches the case sensitive filter. This option may also
# be used with the `test_skip_build` tasks.
grunt test --filter Home

# Run tests and skips the build process:
grunt test_skip_build

# Run tests in the browser, viewable at http://localhost:8888/tests/runner
grunt test_browser
```

### `grunt test_ci`

Runs unit tests like `grunt test` but with output designed for continuous
integration environments.

### `grunt nightwatch`

Runs systems tests using [Nightwatch](http://nightwatchjs.org/), a browser automation testing framework.

```sh
# Run system tests:
grunt nightwatch

# Run a group of system tests:
grunt nightwatch --group path/to/my/tests/

# Run a specific system test:
grunt nightwatch --test path/to/my/tests/test.js

# Run all tests, parallelized by group:
grunt nightwatch-parallel
```

For more information on systems testing configuration, checkout the Nightwatch [documentation](http://nightwatchjs.org/guide#running-tests).

Device testing can also be accomplished using [Appium](http://appium.io). This
requires the Android/iOS development environment to be set up (eg. `$ANDROID_HOME`
pointing to Android SDK, Xcode installed with simulators, etc). To run on a real
device, connect it to your computer.

```
# Run tests on a local Android device using Appium:
grunt android

# Runs tests on a local iOS device using Appium:
grunt ios
```

Device testing on Android emulators and iOS simulators can also be done through
[Sauce Labs](https://saucelabs.com). Specify environment variables `SAUCE_USERNAME` and `SAUCE_ACCESS_KEY`.

```
# Run system tests on an Android emulater.
grunt sauce-android

# Run system tests on an iOS emulator.
grunt sauce-ios
```

## Testing

For information on automated testing with Adaptive.js, checkout the [documentation](https://adaptivejs.mobify.com/page/automated-testing).