define([
    '$',
    'resizeImages',
    'descript',
    'adaptivejs/utils',
    'adaptivejs/defaults',
    'settings',
    'global/includes/header/header-context',
    'global/includes/footer/footer-context',
    'dust!global/base',
],
function($, ResizeImages, Descript, Utils, Defaults, Settings, header, footer, baseTemplate) {
    var descript;

    /**
     * Grab the default cache breaker variable from the Mobify Config
     */
    if (ResizeImages && Settings) {
        ResizeImages.defaults.cacheBreaker = Settings.cacheBreaker;
    }

    /**
     *  Grabs the images which you would like to run through
     *  imageResizer and sends them away. Can be setup
     *  with more profiles for different types of images
     *  if needed.
     */
    var resizeImages = function() {
        var $imgs = $('img');
        var defaultOpts = {
            projectName: Defaults.projectName
        };

        ResizeImages.resize($imgs, defaultOpts);

        return $imgs;
    };

    return {
        template: baseTemplate,
        includes: {
            header: header,
            footer: footer
        },
        /**
        * preProcess receives a context as a paramater and should return
        * that context with any modifications the user needs. This runs
        * before keys in `context` are executed
        */
        preProcess: function(context) {
            // Transforms should take place here rather then within `context`.

            // An example of a DOM transform:
            $('head').find('meta[name="viewport"]').remove();
            $('style, link[rel="stylesheet"]').remove();

            // Use Descript to manipulate the desktop scripts. Please see
            // https://github.com/mobify/descript for detailed documentation.
            descript = Descript.init();

            return context;
        },

        /**
        * postProcess receives a context as a paramater and should return
        * that context with any modifications the user needs. This runs
        * after keys in `context` are executed
        */
        postProcess: function(context) {
            // Transforms should take place here rather then within `context`.

            // Uncomment the following line to use Mobify's image resizer:
            // resizeImages();

            // Add the current `t-template-name` class to the body
            var $body = $('body');
            $body.last().addClass('t-' + context.templateName);

            return context;
        },
        context: {
            templateName: 'base',
            html: function() {
                return $('html');
            },
            head: function() {
                return $('head');
            },
            body: function() {
                return $('body');
            },
            desktopScripts: function() {
                return descript.get('default');
            }
        }
    };

});
